
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.WebKit2.Objects.UserContentManager
    ( 

-- * Exported types
    UserContentManager(..)                  ,
    UserContentManagerK                     ,
    toUserContentManager                    ,
    noUserContentManager                    ,


 -- * Methods
-- ** userContentManagerAddScript
    userContentManagerAddScript             ,


-- ** userContentManagerAddStyleSheet
    userContentManagerAddStyleSheet         ,


-- ** userContentManagerNew
    userContentManagerNew                   ,


-- ** userContentManagerRegisterScriptMessageHandler
    userContentManagerRegisterScriptMessageHandler,


-- ** userContentManagerRemoveAllScripts
    userContentManagerRemoveAllScripts      ,


-- ** userContentManagerRemoveAllStyleSheets
    userContentManagerRemoveAllStyleSheets  ,


-- ** userContentManagerUnregisterScriptMessageHandler
    userContentManagerUnregisterScriptMessageHandler,




 -- * Signals
-- ** ScriptMessageReceived
    UserContentManagerScriptMessageReceivedCallback,
    UserContentManagerScriptMessageReceivedCallbackC,
    UserContentManagerScriptMessageReceivedSignalInfo,
    afterUserContentManagerScriptMessageReceived,
    mkUserContentManagerScriptMessageReceivedCallback,
    noUserContentManagerScriptMessageReceivedCallback,
    onUserContentManagerScriptMessageReceived,
    userContentManagerScriptMessageReceivedCallbackWrapper,
    userContentManagerScriptMessageReceivedClosure,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.WebKit2.Types
import GI.WebKit2.Callbacks
import qualified GI.GObject as GObject

newtype UserContentManager = UserContentManager (ForeignPtr UserContentManager)
foreign import ccall "webkit_user_content_manager_get_type"
    c_webkit_user_content_manager_get_type :: IO GType

type instance ParentTypes UserContentManager = UserContentManagerParentTypes
type UserContentManagerParentTypes = '[GObject.Object]

instance GObject UserContentManager where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_webkit_user_content_manager_get_type
    

class GObject o => UserContentManagerK o
instance (GObject o, IsDescendantOf UserContentManager o) => UserContentManagerK o

toUserContentManager :: UserContentManagerK o => o -> IO UserContentManager
toUserContentManager = unsafeCastTo UserContentManager

noUserContentManager :: Maybe UserContentManager
noUserContentManager = Nothing

-- signal UserContentManager::script-message-received
type UserContentManagerScriptMessageReceivedCallback =
    JavascriptResult ->
    IO ()

noUserContentManagerScriptMessageReceivedCallback :: Maybe UserContentManagerScriptMessageReceivedCallback
noUserContentManagerScriptMessageReceivedCallback = Nothing

type UserContentManagerScriptMessageReceivedCallbackC =
    Ptr () ->                               -- object
    Ptr JavascriptResult ->
    Ptr () ->                               -- user_data
    IO ()

foreign import ccall "wrapper"
    mkUserContentManagerScriptMessageReceivedCallback :: UserContentManagerScriptMessageReceivedCallbackC -> IO (FunPtr UserContentManagerScriptMessageReceivedCallbackC)

userContentManagerScriptMessageReceivedClosure :: UserContentManagerScriptMessageReceivedCallback -> IO Closure
userContentManagerScriptMessageReceivedClosure cb = newCClosure =<< mkUserContentManagerScriptMessageReceivedCallback wrapped
    where wrapped = userContentManagerScriptMessageReceivedCallbackWrapper cb

userContentManagerScriptMessageReceivedCallbackWrapper ::
    UserContentManagerScriptMessageReceivedCallback ->
    Ptr () ->
    Ptr JavascriptResult ->
    Ptr () ->
    IO ()
userContentManagerScriptMessageReceivedCallbackWrapper _cb _ js_result _ = do
    js_result' <- (newBoxed JavascriptResult) js_result
    _cb  js_result'

onUserContentManagerScriptMessageReceived :: (GObject a, MonadIO m) => a -> UserContentManagerScriptMessageReceivedCallback -> m SignalHandlerId
onUserContentManagerScriptMessageReceived obj cb = liftIO $ connectUserContentManagerScriptMessageReceived obj cb SignalConnectBefore
afterUserContentManagerScriptMessageReceived :: (GObject a, MonadIO m) => a -> UserContentManagerScriptMessageReceivedCallback -> m SignalHandlerId
afterUserContentManagerScriptMessageReceived obj cb = connectUserContentManagerScriptMessageReceived obj cb SignalConnectAfter

connectUserContentManagerScriptMessageReceived :: (GObject a, MonadIO m) =>
                                                  a -> UserContentManagerScriptMessageReceivedCallback -> SignalConnectMode -> m SignalHandlerId
connectUserContentManagerScriptMessageReceived obj cb after = liftIO $ do
    cb' <- mkUserContentManagerScriptMessageReceivedCallback (userContentManagerScriptMessageReceivedCallbackWrapper cb)
    connectSignalFunPtr obj "script-message-received" cb' after

type instance AttributeList UserContentManager = UserContentManagerAttributeList
type UserContentManagerAttributeList = ('[ ] :: [(Symbol, *)])

data UserContentManagerScriptMessageReceivedSignalInfo
instance SignalInfo UserContentManagerScriptMessageReceivedSignalInfo where
    type HaskellCallbackType UserContentManagerScriptMessageReceivedSignalInfo = UserContentManagerScriptMessageReceivedCallback
    connectSignal _ = connectUserContentManagerScriptMessageReceived

type instance SignalList UserContentManager = UserContentManagerSignalList
type UserContentManagerSignalList = ('[ '("notify", GObject.ObjectNotifySignalInfo), '("script-message-received", UserContentManagerScriptMessageReceivedSignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method UserContentManager::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- hInArgs : []
-- returnType : TInterface "WebKit2" "UserContentManager"
-- throws : False
-- Skip return : False

foreign import ccall "webkit_user_content_manager_new" webkit_user_content_manager_new :: 
    IO (Ptr UserContentManager)


userContentManagerNew ::
    (MonadIO m) =>
    m UserContentManager
userContentManagerNew  = liftIO $ do
    result <- webkit_user_content_manager_new
    checkUnexpectedReturnNULL "webkit_user_content_manager_new" result
    result' <- (wrapObject UserContentManager) result
    return result'

-- method UserContentManager::add_script
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "script", argType = TInterface "WebKit2" "UserScript", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "script", argType = TInterface "WebKit2" "UserScript", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_user_content_manager_add_script" webkit_user_content_manager_add_script :: 
    Ptr UserContentManager ->               -- _obj : TInterface "WebKit2" "UserContentManager"
    Ptr UserScript ->                       -- script : TInterface "WebKit2" "UserScript"
    IO ()


userContentManagerAddScript ::
    (MonadIO m, UserContentManagerK a) =>
    a ->                                    -- _obj
    UserScript ->                           -- script
    m ()
userContentManagerAddScript _obj script = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let script' = unsafeManagedPtrGetPtr script
    webkit_user_content_manager_add_script _obj' script'
    touchManagedPtr _obj
    touchManagedPtr script
    return ()

-- method UserContentManager::add_style_sheet
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "stylesheet", argType = TInterface "WebKit2" "UserStyleSheet", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "stylesheet", argType = TInterface "WebKit2" "UserStyleSheet", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_user_content_manager_add_style_sheet" webkit_user_content_manager_add_style_sheet :: 
    Ptr UserContentManager ->               -- _obj : TInterface "WebKit2" "UserContentManager"
    Ptr UserStyleSheet ->                   -- stylesheet : TInterface "WebKit2" "UserStyleSheet"
    IO ()


userContentManagerAddStyleSheet ::
    (MonadIO m, UserContentManagerK a) =>
    a ->                                    -- _obj
    UserStyleSheet ->                       -- stylesheet
    m ()
userContentManagerAddStyleSheet _obj stylesheet = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let stylesheet' = unsafeManagedPtrGetPtr stylesheet
    webkit_user_content_manager_add_style_sheet _obj' stylesheet'
    touchManagedPtr _obj
    touchManagedPtr stylesheet
    return ()

-- method UserContentManager::register_script_message_handler
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "webkit_user_content_manager_register_script_message_handler" webkit_user_content_manager_register_script_message_handler :: 
    Ptr UserContentManager ->               -- _obj : TInterface "WebKit2" "UserContentManager"
    CString ->                              -- name : TBasicType TUTF8
    IO CInt


userContentManagerRegisterScriptMessageHandler ::
    (MonadIO m, UserContentManagerK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- name
    m Bool
userContentManagerRegisterScriptMessageHandler _obj name = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    name' <- textToCString name
    result <- webkit_user_content_manager_register_script_message_handler _obj' name'
    let result' = (/= 0) result
    touchManagedPtr _obj
    freeMem name'
    return result'

-- method UserContentManager::remove_all_scripts
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_user_content_manager_remove_all_scripts" webkit_user_content_manager_remove_all_scripts :: 
    Ptr UserContentManager ->               -- _obj : TInterface "WebKit2" "UserContentManager"
    IO ()


userContentManagerRemoveAllScripts ::
    (MonadIO m, UserContentManagerK a) =>
    a ->                                    -- _obj
    m ()
userContentManagerRemoveAllScripts _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    webkit_user_content_manager_remove_all_scripts _obj'
    touchManagedPtr _obj
    return ()

-- method UserContentManager::remove_all_style_sheets
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_user_content_manager_remove_all_style_sheets" webkit_user_content_manager_remove_all_style_sheets :: 
    Ptr UserContentManager ->               -- _obj : TInterface "WebKit2" "UserContentManager"
    IO ()


userContentManagerRemoveAllStyleSheets ::
    (MonadIO m, UserContentManagerK a) =>
    a ->                                    -- _obj
    m ()
userContentManagerRemoveAllStyleSheets _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    webkit_user_content_manager_remove_all_style_sheets _obj'
    touchManagedPtr _obj
    return ()

-- method UserContentManager::unregister_script_message_handler
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit2" "UserContentManager", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_user_content_manager_unregister_script_message_handler" webkit_user_content_manager_unregister_script_message_handler :: 
    Ptr UserContentManager ->               -- _obj : TInterface "WebKit2" "UserContentManager"
    CString ->                              -- name : TBasicType TUTF8
    IO ()


userContentManagerUnregisterScriptMessageHandler ::
    (MonadIO m, UserContentManagerK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- name
    m ()
userContentManagerUnregisterScriptMessageHandler _obj name = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    name' <- textToCString name
    webkit_user_content_manager_unregister_script_message_handler _obj' name'
    touchManagedPtr _obj
    freeMem name'
    return ()


